@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -1071,10 +1071,10 @@ static dispatch_once_t  singletonOnceToken;
   TreeContext  *oldContext = oldControl.treeContext;
   ItemPathModel  *pathModel = oldControl.pathModelView.pathModel;
     
-  DerivedDirViewWindowCreator  *windowCreator = [DerivedDirViewWindowCreator alloc];
-  [[windowCreator initWithWindowManager: windowManager
-                             targetPath: pathModel
-                               settings: controlSettings] autorelease];
+  DerivedDirViewWindowCreator  *windowCreator =
+    [[[DerivedDirViewWindowCreator alloc] initWithWindowManager: windowManager
+                                                     targetPath: pathModel
+                                                       settings: controlSettings] autorelease];
 
   filterSet = [MainMenuControl updateFiltersIfNeeded: filterSet];
 
@@ -1145,10 +1145,11 @@ static dispatch_once_t  singletonOnceToken;
     pathModel = [[pathModel copy] autorelease];
   }
 
-  DirectoryViewControl  *newControl = [DirectoryViewControl alloc];
-  [[newControl initWithAnnotatedTreeContext: oldControl.annotatedTreeContext
-                                  pathModel: pathModel
-                                   settings: oldControl.directoryViewControlSettings] autorelease];
+  DirectoryViewControlSettings  *oldSettings = oldControl.directoryViewControlSettings;
+  DirectoryViewControl  *newControl =
+    [[[DirectoryViewControl alloc] initWithAnnotatedTreeContext: oldControl.annotatedTreeContext
+                                                      pathModel: pathModel
+                                                       settings: oldSettings] autorelease];
 
   // Force loading (and showing) of the window.
   [windowManager addWindow: newControl.window usingTitle: oldControl.window.title];
