@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -48,7 +48,11 @@ extern NSString  *DelayBeforeWelcomeWindowAfterStartupKey;
 extern NSString  *KeyboardNavigationDeltaKey;
 extern NSString  *PackageCheckBehaviorKey;
 extern NSString  *DefaultDisplayFocusKey;
-extern NSString  *SuppressFdaWarningSheetKey;
+
+// Permission checks
+extern NSString  *SuppressFdaWarningsKey;
+extern NSString  *SuppressFdaSuccessKey;
+extern NSString  *RootVolumeBookmarkKey;
 
 extern NSString  *UnlimitedDisplayFocusValue;
 
