@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -51,8 +51,8 @@ NSString  *ShowPackageContentsByDefaultKey_Deprecated = @"showPackageContentsByD
 // Deprecated since 3.1.0
 NSString  *DefaultFilterKey_Deprecated = @"defaultFilter";
 
-// Can be set from the FDA warning sheet
-NSString  *SuppressFdaWarningSheetKey = @"suppressFdaWarningSheet";
+// Can be set from the FDA warning sheets and panels
+NSString  *SuppressFdaWarningsKey = @"suppressFdaWarnings";
 
 /* Note: The preferences below cannot currently be changed from the preferences panel; they are set
  * by the application defaults and can be changed by manually editing the user preferences file.
@@ -72,6 +72,9 @@ NSString  *DelayBeforeWelcomeWindowAfterStartupKey = @"delayBeforeWelcomeWindowA
 NSString  *KeyboardNavigationDeltaKey = @"keyboardNavigationDelta";
 NSString  *PackageCheckBehaviorKey = @"packageCheckBehavior";
 
+NSString  *RootVolumeBookmarkKey = @"rootVolumeBookmark";
+NSString  *SuppressFdaSuccessKey = @"suppressFdaSuccess";
+
 NSString  *UnlimitedDisplayFocusValue = @"unlimited";
 
 @interface PreferencesPanelControl (PrivateMethods)
