@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -82,7 +82,7 @@ extern NSString  *DateTimeFormat;
 
 + (nullable NSString *)stringForTime:(CFAbsoluteTime)time;
 
-- (TextOutput *)createTextOutput:(NSURL *)path;
+- (TextOutput *)newTextOutput:(NSURL *)path;
 
 - (void) appendString:(NSString *)s;
 
