@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -63,7 +63,7 @@ NSLocalizedString(@"Failed to write to file", @"Error message")
 - (BOOL) writeTree:(AnnotatedTreeContext *)tree toFile:(NSURL *)path options:(id)options {
   NSAssert(!textOutput, @"textOutput not nil");
 
-  textOutput = [self createTextOutput: path];
+  textOutput = [self newTextOutput: path];
 
   if (![textOutput open]) {
     error = [[ApplicationError alloc] initWithLocalizedDescription: FAILED_TO_CREATE_FILE];
@@ -133,7 +133,7 @@ NSLocalizedString(@"Failed to write to file", @"Error message")
   }
 }
 
-- (TextOutput *)createTextOutput:(NSURL *)path {
+- (TextOutput *)newTextOutput:(NSURL *)path {
   return [[TextOutput alloc] initWithPath: path];
 }
 
