@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -66,7 +66,7 @@ extern NSString  *AccessedAttr;
 @interface XmlTreeWriter (ProtectedMethods)
 
 // Creates compressed text output.
-- (TextOutput *)createTextOutput:(NSURL *)path;
+- (TextOutput *)newTextOutput:(NSURL *)path;
 
 // Writes the tree in XML format.
 - (void) writeTree:(AnnotatedTreeContext *)tree options:(id)options;
