@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -194,7 +194,7 @@ NSString *escapedXML(NSString *s, CharacterOptions escapeCharMask) {
   [super dealloc];
 }
 
-- (TextOutput *)createTextOutput:(NSURL *)path {
+- (TextOutput *)newTextOutput:(NSURL *)path {
   return [[CompressedTextOutput alloc] initWithPath: path];
 }
 
