@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -39,7 +39,7 @@
   
     _treeDrawer = [[TreeDrawer alloc] initWithScanTree: treeContext.scanTree
                                     treeDrawerSettings: settings];
-    _treeDrawerSettings = settings;
+    _treeDrawerSettings = [settings retain];
 
     settingsLock = [[NSLock alloc] init];
   }
@@ -49,6 +49,10 @@
 - (void) dealloc {
   [treeContext release];
 
+  [_treeDrawer release];
+
+  [_treeDrawerSettings release];
+
   [settingsLock release];
   
   [super dealloc];
@@ -57,7 +61,8 @@
 
 - (void) setTreeDrawerSettings:(TreeDrawerSettings *)settings {
   [settingsLock lock];
-  _treeDrawerSettings = settings;
+  [_treeDrawerSettings release];
+  _treeDrawerSettings = [settings retain];
   [settingsLock unlock];
 }
 
