@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -603,14 +603,13 @@ CFAbsoluteTime convertTimespec(struct timespec ts) {
     flags |= FileItemIsHardlinked;
   }
 
-  ScanTreeRoot  *scanTree = [ScanTreeRoot alloc];
-  [[scanTree initWithLabel: relativePath
-                    parent: treeContext.scanTreeParent
-                     flags: flags
-              creationTime: treeRootURL.creationTime
-          modificationTime: treeRootURL.modificationTime
-                accessTime: treeRootURL.accessTime
-    ] autorelease];
+  ScanTreeRoot  *scanTree = [[[ScanTreeRoot alloc] initWithLabel: relativePath
+                                                          parent: treeContext.scanTreeParent
+                                                           flags: flags
+                                                    creationTime: treeRootURL.creationTime
+                                                modificationTime: treeRootURL.modificationTime
+                                                      accessTime: treeRootURL.accessTime
+                             ] autorelease];
 
   // Reset other state
   totalPhysicalSize = 0;
