@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -81,8 +81,8 @@
                                     scanTime: oldTree.scanTime
                                  monitorPath: pathToMonitor] autorelease];
 
-  DirectoryItem  *scanTree = [ScanTreeRoot alloc];
-  [[scanTree initWithLabel: oldScanTree.label
+  DirectoryItem  *scanTree =
+  [[[ScanTreeRoot alloc] initWithLabel: oldScanTree.label
                     parent: filterResult.scanTreeParent
                      flags: oldScanTree.fileItemFlags
               creationTime: oldScanTree.creationTime
