@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6.1 
+/* GrandPerspective, Version 3.6.2 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -62,6 +62,9 @@
 - (void) dealloc {
   [NSNotificationCenter.defaultCenter removeObserver: self];
 
+  [_colorMapper release];
+  [_colorScheme release];
+
   [super dealloc];
 }
 
